package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.AppAiAssistantDTO;
import com.pjilisense.flxai.service.AppAiAssistantService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * AI助手表
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2024-12-13
 */
@RestController
@RequestMapping("robot/appaiassistant")
@Api(tags="AI助手表")
public class AppAiAssistantController {

    private static Logger logger = LoggerFactory.getLogger(AppAiAssistantController.class);

    @Autowired
    private AppAiAssistantService appAiAssistantService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<AppAiAssistantDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppAiAssistantDTO> page = appAiAssistantService.page(params);

        return new Result<PageData<AppAiAssistantDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<AppAiAssistantDTO> get(@PathVariable("id") Long id){
        AppAiAssistantDTO data = appAiAssistantService.get(id);

        return new Result<AppAiAssistantDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody AppAiAssistantDTO dto){
        //效验数据

        appAiAssistantService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody AppAiAssistantDTO dto){
        //效验数据

        appAiAssistantService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody Long[] ids){
        //效验数据
        appAiAssistantService.delete(ids);

        return new Result();
    }

}